:mod:`pymunk.constraints` Module
--------------------------------

.. container:: custom-index
    
    .. raw:: html
    
        <script type="text/javascript" src='_static/pymunk.js'></script>

.. automodule:: pymunk.constraints
    :special-members: __init__